package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@(!`0````````````(`/@`!````X")```````!``````````(C'````
M`````````$``.``(`$``'``;``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````#S!````````/,$`````````
M`"````````$````&````0,$```````!`P6```````$#!8`````````4`````
M``"`%0``````````(````````@````8```!HP0```````&C!8```````:,%@
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%#E=&0$
M````K+L```````"LNT```````*R[0```````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`K$$.)3T@>FCLB8Y*(F7EQ;TJ3T81````4`````0````(````(!`0``5`
M!(2J`@`!@(8!J$(H`"!/(`0+N*(X3;J$!@I0````4@```%<```!<````70``
M`&0```!F````:````&H```!M`````````&\```!Q````<@```',`````````
M`````'KP2FNA(@L@ZM/O#F[%WQ]&F`7&SMY'+6M_FGPNQ9NVU&34?'Q!CL4@
M_^0.N8WQ#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/+;TQW[H6Q@:@E#UH?Y
MG(%FK\QFQ;F<0,2)!9!#1=7L#!3BGLC5LG'G[U][,F+;[=O-XYX,.I<+I]VC
M:W^IG)OAIP(*H^#[20`````````````````````````````````````M`P``
M$@````````````````````````"L````$@````````````````````````"<
M`0``$@````````````````````````#$`P``$@``````````````````````
M``#?`P``$@````````````````````````!!`P``$@``````````````````
M``````!U`@``$@````````````````````````"H`P``$@``````````````
M```````````,````(``````````````````````````;````(```````````
M``````````````"(`0``$@`````````````````````````H!```$@``````
M``````````````````!C`P``$@````````````````````````!I`0``$@``
M``````````````````````![`0``$@````````````````````````!1`P``
M$@`````````````````````````/`P``$@````````````````````````!H
M`P``$@````````````````````````",`@``$@``````````````````````
M``!Q!```$@`````````````````````````G`@``$@``````````````````
M``````#X````$@`````````````````````````7`@``$@``````````````
M``````````"3`P``$@````````````````````````#2`P``$@``````````
M``````````````#%`0``$@`````````````````````````O!```$@``````
M``````````````````"O`P``$@````````````````````````!!!0``$@``
M``````````````````````"3`@``$@````````````````````````#E`0``
M$@````````````````````````!P`P``$@`````````````````````````P
M`@``$@````````````````````````"A`0``$@``````````````````````
M``"]`P``$@````````````````````````#X`P``$@``````````````````
M```````J`0``$@`````````````````````````O````$@``````````````
M```````````*!```$@````````````````````````!8`0``$@``````````
M``````````````##````$@`````````````````````````(`P``$@``````
M``````````````````#+`P``$@`````````````````````````\`0``$@``
M```````````````````````?!```$@````````````````````````!7`@``
M$@````````````````````````#8`P``$@````````````````````````!;
M!```$@`````````````````````````\!```$@``````````````````````
M``#M`P``$@````````````````````````!)`@``$@``````````````````
M```````4`P``$@````````````````````````"F`0``$@``````````````
M``````````""`P``$@````````````````````````!J!```$@``````````
M``````````````"V`P``$@````````````````````````#G````$@``````
M```````````````````]````$@`````````````````````````8!```$@``
M``````````````````````#2````$@````````````````````````#Y`0``
M$@``````````````````````````!```$@````````````````````````"`
M`@``$@`````````````````````````E`P``$@``````````````````````
M``!+`0``$@````````````````````````!Y`P``$@``````````````````
M``````!-!```$@`````````````````````````8`0``$@``````````````
M``````````!C!```$@````````````````````````"@`P``$@``````````
M```````````````^`@``$@````````````````````````!/````$@``````
M``````````````````#3`0``$@````````````````````````!>````$@``
M``````````````````````"*````$@````````````````````````!#!```
M$@````````````````````````":`P``$@````````````````````````!S
M````$@`````````````````````````&`0``$@``````````````````````
M``!E`@``$@```$`@0`````````````````"Z!0``$0`8`#C&8```````"```
M``````#C!```$@`.`.A<0`````````````````!*!0``$@`-`!!90```````
M;P````````"*!0``$0`8`##&8```````"`````````#.!0``$@`-`%!*0```
M````#`H```````!^!```$@`-`,!90```````*P(```````"[!```$@`-`.!#
M0```````!0````````#I!```$@`-`&!40```````IP0```````">!0``$@`-
M`(!90```````0`````````#M!0``$@`-`/!#0```````UP$```````!T!0``
M$@`+`+@=0`````````````````"4!```$`#Q_T#&8`````````````````#,
M!```$@`-`-!%0```````)`````````#_!```$@`-`+!(0```````2```````
M``!6!0``$0`/``!=0```````!`````````!R!0``$@`-`(!"0```````+0``
M``````"@!```$`#Q_\#68`````````````````">`@``$0`9`%#&8```````
M$P````````#;!0``$@`-`#!)0```````$@$```````!E!0``$``8`"C&8```
M``````````````";````$@```%`@0``````````````````C!0``$@`-``!&
M0```````V@````````"#!```$0`9`$#&8```````"`````````"$!```(0`9
M`$#&8```````"`````````"-!```$`#Q_T#&8`````````````````#9!```
M$@`-`*!<0````````@````````"R`0``$@```&`>0`````````````````"/
M!0``$0`/`,!?0```````ZEL```````!K!0``$@`-`.`B0```````````````
M``!Z!0``$@`-`!!<0```````B0````````!G!0``(``8`"C&8```````````
M``````"%!```(0`9`$#&8```````"``````````O!0``$@`-``!)0```````
M(@`````````-!0``$@`-``!#0```````W@````````#Z!0``$@`-`.!&0```
M````RP$`````````;&EB<&5R;"YS;P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G
M:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`
M4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E
M7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO
M8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])
M=&%I;G1E9%]P='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?
M;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E
M<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R
M`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E
M;%]P='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB<F5S;VQV+G-O+C(`;&EB;G-L+G-O
M+C$`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL
M+G-O+C$`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C
M871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N
M<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V
M<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(V-"]P97)L
M-2]#3U)%`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C
M<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D
M871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M
M>5]P87)?<&P`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A
M9%]M>5]P87)?<&P`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A
M<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'
M3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C(N-0`````"```````#
M``0``@````,``````````P`#```````%``(``P`#``,``````````P`#````
M!``#``,```````,````#``,``P``````!@```````@`#`````P````,``P`#
M``,````"````!P`#``,```````,```````,````"`````P`$`````P`#````
M```````````#``,``````````0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`````0`!`````0`#``,``0`!`````0`!``$``0`#``$``0`!``$`
M!0!'`P``$````&`````4:6D-```'``<&```0````$VEI#0``!@`1!@``$```
M`'(9:0D```4`&P8``!````!T&6D)```$`"<&```0````=1II"0```P`S!@``
M``````$``0#X`@``$`````````!U&FD)```"`#,&````````B,-@```````&
M````"0``````````````0,9@```````%````9P``````````````4,9@````
M```%````8@``````````````J,-@```````'`````0``````````````L,-@
M```````'`````@``````````````N,-@```````'`````P``````````````
MP,-@```````'````!```````````````R,-@```````'````!0``````````
M````T,-@```````'````!@``````````````V,-@```````'````!P``````
M````````X,-@```````'````"```````````````Z,-@```````'````:P``
M````````````\,-@```````'````"P``````````````^,-@```````'````
M#````````````````,1@```````'````#0``````````````",1@```````'
M````#@``````````````$,1@```````'````#P``````````````&,1@````
M```'````$```````````````(,1@```````'````$0``````````````*,1@
M```````'````$@``````````````,,1@```````'````$P``````````````
M.,1@```````'````%```````````````0,1@```````'````%0``````````
M````2,1@```````'````%@``````````````4,1@```````'````%P``````
M````````6,1@```````'````&```````````````8,1@```````'````&0``
M````````````:,1@```````'````&@``````````````<,1@```````'````
M&P``````````````>,1@```````'````'```````````````@,1@```````'
M````'0``````````````B,1@```````'````'@``````````````D,1@````
M```'````'P``````````````F,1@```````'````(```````````````H,1@
M```````'````(0``````````````J,1@```````'````(@``````````````
ML,1@```````'````(P``````````````N,1@```````'````)```````````
M````P,1@```````'````)0``````````````R,1@```````'````)@``````
M````````T,1@```````'````)P``````````````V,1@```````'````4```
M````````````X,1@```````'````90``````````````Z,1@```````'````
M*```````````````\,1@```````'````*0``````````````^,1@```````'
M````*@```````````````,5@```````'````*P``````````````",5@````
M```'````+```````````````$,5@```````'````+0``````````````&,5@
M```````'````+@``````````````(,5@```````'````+P``````````````
M*,5@```````'````,```````````````,,5@```````'````,0``````````
M````.,5@```````'````,@``````````````0,5@```````'````,P``````
M````````2,5@```````'````-```````````````4,5@```````'````-0``
M````````````6,5@```````'````-@``````````````8,5@```````'````
M-P``````````````:,5@```````'````.```````````````<,5@```````'
M````.0``````````````>,5@```````'````.@``````````````@,5@````
M```'````.P``````````````B,5@```````'````/```````````````D,5@
M```````'````/0``````````````F,5@```````'````/@``````````````
MH,5@```````'````/P``````````````J,5@```````'````0```````````
M````L,5@```````'````00``````````````N,5@```````'````0@``````
M````````P,5@```````'````0P``````````````R,5@```````'````1```
M````````````T,5@```````'````10``````````````V,5@```````'````
M1@``````````````X,5@```````'````1P``````````````Z,5@```````'
M````2```````````````\,5@```````'````20``````````````^,5@````
M```'````2@```````````````,9@```````'````2P``````````````",9@
M```````'````3```````````````$,9@```````'````30``````````````
M&,9@```````'````3@``````````````(,9@```````'````3P``````````
M````2(/L".A+!0``Z-H%``#HY3X``$B#Q`C#_S7"I2``_R7$I2``#Q]``/\E
MPJ4@`&@`````Z>#_____);JE(`!H`0```.G0_____R6RI2``:`(```#IP/__
M__\EJJ4@`&@#````Z;#_____):*E(`!H!````.F@_____R6:I2``:`4```#I
MD/____\EDJ4@`&@&````Z8#_____)8JE(`!H!P```.EP_____R6"I2``:`@`
M``#I8/____\E>J4@`&@)````Z5#_____)7*E(`!H"@```.E`_____R5JI2``
M:`L```#I,/____\E8J4@`&@,````Z2#_____)5JE(`!H#0```.D0_____R52
MI2``:`X```#I`/____\E2J4@`&@/````Z?#^____)4*E(`!H$````.G@_O__
M_R4ZI2``:!$```#IT/[___\E,J4@`&@2````Z<#^____)2JE(`!H$P```.FP
M_O___R4BI2``:!0```#IH/[___\E&J4@`&@5````Z9#^____)1*E(`!H%@``
M`.F`_O___R4*I2``:!<```#I</[___\E`J4@`&@8````Z6#^____)?JD(`!H
M&0```.E0_O___R7RI"``:!H```#I0/[___\EZJ0@`&@;````Z3#^____)>*D
M(`!H'````.D@_O___R7:I"``:!T```#I$/[___\ETJ0@`&@>````Z0#^____
M)<JD(`!H'P```.GP_?___R7"I"``:"````#IX/W___\ENJ0@`&@A````Z=#]
M____);*D(`!H(@```.G`_?___R6JI"``:",```#IL/W___\EHJ0@`&@D````
MZ:#]____)9JD(`!H)0```.F0_?___R62I"``:"8```#I@/W___\EBJ0@`&@G
M````Z7#]____)8*D(`!H*````.E@_?___R5ZI"``:"D```#I4/W___\E<J0@
M`&@J````Z4#]____)6JD(`!H*P```.DP_?___R5BI"``:"P```#I(/W___\E
M6J0@`&@M````Z1#]____)5*D(`!H+@```.D`_?___R5*I"``:"\```#I\/S_
M__\E0J0@`&@P````Z>#\____)3JD(`!H,0```.G0_/___R4RI"``:#(```#I
MP/S___\E*J0@`&@S````Z;#\____)2*D(`!H-````.F@_/___R4:I"``:#4`
M``#ID/S___\E$J0@`&@V````Z8#\____)0JD(`!H-P```.EP_/___R4"I"``
M:#@```#I8/S___\E^J,@`&@Y````Z5#\____)?*C(`!H.@```.E`_/___R7J
MHR``:#L```#I,/S___\EXJ,@`&@\````Z2#\____)=JC(`!H/0```.D0_/__
M_R72HR``:#X```#I`/S___\ERJ,@`&@_````Z?#[____)<*C(`!H0````.G@
M^____R6ZHR``:$$```#IT/O___\ELJ,@`&A"````Z<#[____):JC(`!H0P``
M`.FP^____R6BHR``:$0```#IH/O___\EFJ,@`&A%````Z9#[____)9*C(`!H
M1@```.F`^____R6*HR``:$<```#I</O___\E@J,@`&A(````Z6#[____)7JC
M(`!H20```.E0^____R5RHR``:$H```#I0/O___\E:J,@`&A+````Z3#[____
M)6*C(`!H3````.D@^____R5:HR``:$T```#I$/O___\E4J,@`&A.````Z0#[
M____)4JC(`!H3P```.GP^O__,>U)B=%>2(GB2(/D\%!42<?`H%Q``$C'P1!<
M0`!(Q\?`64``Z/?[___TD)!(@^P(2(L%<:`@`$B%P'0"_]!(@\0(PY"0D)"0
MD)"0D)"0D)!52(GE4TB#[`B`/2BC(```=4N[6,%@`$B+!2*C(`!(@>M0P6``
M2,'[`TB#ZP%(.=AS)&8/'T0``$B#P`%(B07]HB``_Q3%4,%@`$B+!>^B(`!(
M.=ARXL8%VZ(@``%(@\0(6\G#9F9F+@\?A```````2(,]N)T@``!52(GE=!*X
M`````$B%P'0(OV#!8`#)_^#)PY"0D)"0D)"0D)"0D)"005<QR4%6055!5%53
M2(U?.$B![!`"``!(C70DB`\?0`!(BQ0+2(G028G02,'@"$G!X!A!@^#_)0``
M_P!,"<!)B=!)P>@(08'@`/\``$P)P$F)T$G!Z!A!@>#_````3`G`28G02<'H
M($B)!$Y,B<!)P>`82,'@"$&#X/\E``#_`$P)P$F)T$C!ZCA)P>@H08'@`/\`
M`$P)P$@)T$B)1$X(2(/!"$B#^4`/A7/___](C59H2('&:`(```\?A```````
M2(M"V$@S`D@S0JA(,T*82(G!2`'`2,'I'T@)P8/A_TB)2AA(@\((2#GR==1,
MBP=(BU\@3(M/"$R+5Q!,BU\82(G:3(G`2`-4)(A,B<%(P>@;2,'A!4R)WD@#
M="202`G(3(G!@^#_2/?12(VL`IEY@EI,B<A,B=)(]]!,(<I,(=%,(=A("=!,
MB<H!Q4R)R$C!XAY(P>@"28GM2`G0@^#_2(G"3"'"2`G*2(GI3(VD%IEY@EI(
MB>I(P>$%2,'J&TR)UD@#="282`G*3(G!1HTD(DR)PDC!Z0)(P>(>2`G12(GJ
M@^'_2/?222'-2"'"3`GJ38GE2(VT%IEY@EI,B>))P>4%2,'J&TP)ZDV)Y8TT
M,DB)ZDC!Y1Y(P>H"2`GJ2`-$)*!,B>6#XO](]]5)(=5((<U(`TPDJ$P)[4F)
M]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A!B>U"C2PH3(G@2<'D'DC!Z`))B?5,
M">!)B?2#X/])]]1)(<5)(=1(`U0DL$T)[$F)[4Z-I"&9>8):2(GI2<'E!4C!
MZ1M,">E)B>U&C20A2(GQ2,'F'DC!Z0)("?%(B>Z#X?](]]9)(<U((<9,">Y-
MB>5(C;0RF7F"6DR)XDG!Y05(P>H;3`GJ38GEC30R2(GJ2,'E'DC!Z@)(">I(
M`T0DN$R)Y8/B_TCWU4DAU4@AS4@#3"3`3`GM28GU2(VL*)EY@EI(B?!)P>4%
M2,'H&TP)Z$&)[DF)]4*-+#!,B>!)P>0>2,'H`DP)X$F)](/@_TGWU$DAQ4DA
MU$@#5"3(30GL28GM3HVD(9EY@EI(B>E)P>4%2,'I&TP)Z4F)[4:-)"%(B?%(
MP>8>2,'I`D@)\4B)[H/A_TCWUDDAS4@AQDP)[DV)Y4B-M#*9>8):3(GB2<'E
M!4C!ZAM,">I-B>6--#)(B>I(P>4>2,'J`D@)ZD@#1"303(GE@^+_2/?522'5
M2"'-2`-,)-A,">U)B?5(C:PHF7F"6DB)\$G!Y05(P>@;3`GH08GO28GU0HTL
M.$R)X$G!Y!Y(P>@"3`G@28GT@^#_2??422'%22'42`-4).!-">Q)B>U.C:0A
MF7F"6DB)Z4G!Y05(P>D;3`GI28GM1HTD(4B)\4C!YAY(P>D"2`GQ2(GN@^'_
M2/?622'-2"'&3`GN38GE2(VT,IEY@EI,B>))P>4%2,'J&TP)ZDV)Y8TT,DB)
MZDC!Y1Y(P>H"2`GJ2`-$).A,B>6#XO](]]5)(=5((<U(`TPD\$P)[4F)]4B-
MK"B9>8):2(GP2<'E!4C!Z!M,">A!B>U"C2PH3(G@2<'D'DC!Z`))B?5,">!)
MB?2#X/])]]1)(<5)(=1(`U0D^$T)[$F)[4Z-I"&9>8):2(GI2<'E!4C!Z1M,
M">E)B>U&C20A2(GQ2,'F'DC!Z0)("?%(B>Z#X?](]]9)(<U((<9,">Y-B>5(
MC;0RF7F"6DR)XDG!Y05(P>H;3`GJ38GEC30R2(GJ2,'E'DC!Z@)(">I(`P0D
M3(GE@^+_2/?522'52"'-2`-,)`A,">U)B?5(C:PHF7F"6DB)\$G!Y05(P>@;
M3`GH08GN28GU0HTL,$R)X$G!Y!Y(P>@"3`G@28GT@^#_2??422'%22'42`-4
M)!!-">Q)B>U.C:0AF7F"6DB)Z4G!Y05(P>D;3`GI28GM1HTD(4B)\4C!YAY(
MP>D"2`GQ2(GN@^'_2/?622'-2"'&3`GN38GE2(VT,IEY@EI,B>))P>4%2,'J
M&TP)ZDV)Y8TT,DB)ZDC!Y1Y(P>H"2`GJ2`-$)!A,B>6#XO](]]5)(=5((<U(
M`TPD($P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A!B>])B?5"C2PX3(G@
M2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)(=1(`U0D*$T)[$Z-K"&9>8):2(GI
M28GL2<'D!4C!Z1M,">%&C2PI2(GQ2,'F'DC!Z0)("?&#X?](B<Y(,<9(,>Y,
MC:0RH>O9;DR)ZDR)[DC!Y@5(P>H;2`GR1HTD(DB)ZDC!Y1Y(P>H"2`GJ@^+_
M2`-$)#!(B=9(,<Y(`TPD.$PQ[DB-K#"AZ]EN3(G@3(GF2,'F!4C!Z!M("?")
M[HTL,$R)Z$G!Y1Y(P>@"3`GH28GM@^#_2<'E!4B)QD@QUD@#5"1`3#'F2(VT
M,:'KV6Y(B>E(P>D;3`GIC30Q3(GA2<'D'DC!Z0),">%)B?6#X?])P>4%28G,
M23'$2`-$)$A),>Q.C:0BH>O9;DB)\DC!ZAM,">I&C20B2(GJ2,'E'DC!Z@)(
M">I-B>6#XO](B=5(,<U(,?5)P>4%2`-,)%!(C:PHH>O9;DR)X$C!Z!M,">A!
MB>U"C2PH2(GP2,'F'DC!Z`)("?!)B>V#X/])P>4%2(G&2#'62`-4)%A,,>9(
MC;0QH>O9;DB)Z4C!Z1M,">F--#%,B>%)P>0>2,'I`DP)X4F)]8/A_TG!Y05)
MB<Q),<1(`T0D8$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD:-)")(B>I(P>4>2,'J
M`D@)ZDV)Y8/B_TG!Y05(B=5(,<U(,?5(C:PHH>O9;DR)X$C!Z!M,">A!B>Y(
M`TPD:$*-+#!(B?!(P>8>2,'H`D@)\$F)[8/@_TG!Y05(B<9(,=9(`U0D<$PQ
MYDB-M#&AZ]EN2(GI2,'I&TP)Z8TT,4R)X4G!Y!Y(P>D"3`GA28GU@^'_2<'E
M!4F)S$DQQ$@#1"1X23'L3HVD(J'KV6Y(B?)(P>H;3`GJ1HTD(DB)ZDC!Y1Y(
MP>H"2`GJ38GE@^+_2<'E!4B)U4@QS4@Q]4B-K"BAZ]EN3(G@2,'H&TP)Z$&)
M[T*-+#A(B?!(P>8>2,'H`D@)\$@#C"2`````28GM@^#_2<'E!4B)QD@QUD@#
ME"2(````3#'F2(VT,:'KV6Y(B>E(P>D;3`GIC30Q3(GA2<'D'DC!Z0),">%)
MB?6#X?])P>4%28G,23'$2`.$))````!),>Q.C:0BH>O9;DB)\DC!ZAM,">I&
MC20B2(GJ2,'E'DC!Z@)(">I-B>6#XO])P>4%2(G52#'-2`.,))@```!(,?5(
MC:PHH>O9;DR)X$C!Z!M,">A!B>U"C2PH2(GP2,'F'DC!Z`)("?!)B>V#X/](
MB<9(,=9)P>4%2`.4)*````!,,>9(C;0QH>O9;DB)Z4C!Z1M,">F--#%,B>%)
MP>0>2,'I`DP)X4F)]8/A_TG!Y05)B<Q),<1(`X0DJ````$DQ[$Z-I"*AZ]EN
M2(GR2,'J&TP)ZD:-)")(B>I(P>4>2,'J`D@)ZDV)Y8/B_TG!Y05(B=5(,<U(
M`XPDL````$@Q]4B-K"BAZ]EN3(G@2,'H&TP)Z$&)[D*-+#!(B?!(P>8>2,'H
M`D@)\(/@_TB)QD@QUDPQYDR-K#&AZ]EN2(GI2(GN2,'I&TC!Y@5(`Y0DN```
M`$@)\4R)YDG!Y!Y(P>X"1HTL*4P)YH/F_TB)\4@QP4@#A"3`````2#'I3(VD
M"J'KV6Y,B>I,B>E(P>$%2,'J&T@)RDB)Z4C!Y1Y(P>D"1HTD(D@)Z8/A_TB)
MRD@Q\DPQZDB-K!"AZ]EN3(G@3(GB2,'B!4C!Z!M("=!!B>],B>I"C2PX2<'E
M'KC<O!N/2,'J`DP)ZDF)Q4P#K"3(````@^+_28G622'.28UT-0!)B=5)"<U-
M(>5-"?5)B>Y.C2PN2(GN2<'F!4C![AM,"?9&C2PN3(GF2<'D'DC![@),">9)
MB<1,`Z0DT````(/F_TF)]DDAUDF-#`Q)B?1)"=1)(>Q-"?1-B>Y.C20A3(GI
M2<'F!4C!Z1M,"?%&C20A2(GI2,'E'DC!Z0)(">E(B<5(`ZPDV````(/A_TF)
MSDDA]DB-5!4`2(G-2`GU3"'M3`GU38GF2(TL*DR)XDG!Y@5(P>H;3`GR08GN
M0HTL,DR)ZDG!Y1Y(P>H"3`GJ28G%3`.L).````"#XO])B=9)(<Y)C70U`$F)
MU4D)S4TAY4T)]4F)[DZ-+"Y(B>Y)P>8%2,'N&TP)]D:-+"Y,B>9)P>0>2,'N
M`DP)YDF)Q$P#I"3H````@^;_28GV22'628T,#$F)]$D)U$DA[$T)]$V)[DZ-
M)"%,B>E)P>8%2,'I&TP)\4:-)"%(B>E(P>4>2,'I`D@)Z4B)Q4@#K"3P````
M@^'_28G.22'V2(U4%0!(B<U("?5,(>U,"?5-B>9(C2PJ3(GB2<'F!4C!ZAM,
M"?)!B>]"C2PZ3(GJ2<'E'DC!Z@),">I)B<5,`ZPD^````(/B_TF)UDF-=#4`
M28G520G-22'.32'E30GU28GN3HTL+DB)[DG!Y@5(P>X;3`GV1HTL+DR)YDG!
MY!Y(P>X"3`GF28G$3`.D)``!``"#YO])B?9)(=9)C0P,28GT20G422'L30GT
M38GN3HTD(4R)Z4G!Y@5(P>D;3`GQ1HTD(4B)Z4C!Y1Y(P>D"2`GI2(G%2`.L
M)`@!``"#X?])B<Y)(?9(C505`$B)S4@)]4PA[4P)]4V)YDB-+"I,B>))P>8%
M2,'J&TP)\D&)[D*-+#),B>I)P>4>2,'J`DP)ZDF)Q4P#K"00`0``@^+_28G6
M22'.28UT-0!)B=5)"<U-(>5-"?5)B>Y.C2PN2(GN2<'F!4C![AM,"?9&C2PN
M3(GF2<'D'DC![@),">9)B<1,`Z0D&`$``(/F_TF)]DDAUDF-#`Q)B?1)"=1)
M(>Q-"?1-B>Y.C20A3(GI2<'F!4C!Z1M,"?%&C20A2(GI2,'E'DC!Z0)(">E(
MB<5(`ZPD(`$``(/A_TF)SDDA]DB-5!4`2(G-2`GU3"'M3`GU38GF2(TL*DR)
MXDG!Y@5(P>H;3`GR08GO0HTL.DR)ZDG!Y1Y(P>H"3`GJ28G%3`.L)"@!``"#
MXO])B=9)(<Y)C70U`$F)U4D)S4TAY4T)]4F)[DZ-+"Y(B>Y)P>8%2,'N&TP)
M]D:-+"Y,B>9)P>0>2,'N`DP)YDF)Q$P#I"0P`0``@^;_28GV22'628T,#$F)
M]$D)U$DA[$T)]$V)[DZ-)"%,B>E)P>8%2,'I&TP)\4:-)"%(B>E(P>4>2,'I
M`D@)Z4B)Q4@#K"0X`0``@^'_28G.22'V2(U4%0!(B<U("?5,(>U,"?5-B>9(
MC2PJ3(GB2<'F!4C!ZAM,"?)!B>Y"C2PR3(GJ2<'E'DC!Z@),">I)B<5,`ZPD
M0`$``(/B_TF)UDDASDF-=#4`28G520G-32'E30GU28GN3HTL+DB)[DG!Y@5(
MP>X;3`GV1HTL+DR)YDG!Y!Y(P>X"3`GF28G$3`.D)$@!``"#YO])B?9)(=9)
MC0P,28GT20G422'L30GT38GN3HTD(4R)Z4G!Y@5(P>D;3`GQ1HTD(4B)Z4C!
MY1Y(P>D"2`GI2(G%2`.L)%`!``"#X?])B<Y(C505`$B)S4@)]4DA]DPA[4P)
M]4V)YDB-+"I,B>))P>8%2,'J&TP)\D&)[T*-+#I,B>I)P>4>2,'J`DP)ZDF)
MQ4P#K"18`0``@^+_2`.$)&`!``!)B=9)(<Y)C70U`$F)U4D)S4B-#`A-(>5-
M"?5)B>Y.C2PN2(GN2<'F!4C![AM,"?9&C2PN3(GF2<'D'DC![@),">:#YO](
MB?!)B?1("=!)(=1((>A,">!)B>Q(P>4>3(TT`4R)Z$R)Z4C!X05(P>@;2<'L
M`D@)R$D)[$:--#"XUL%BRD&#Y/](B<%(`XPD:`$``$R)]4C!Y05(C1013(GA
M2#'Q3#'I2(T,"DR)\DC!ZAM(">I,B>U)P>4>1(T\"DB)PD@#E"1P`0``2,'M
M`DP)[4R)^8/E_TC!X05(C30R2(GJ3#'B3#'R3(TL%DR)^DC!ZAM("<I,B?%)
MP>8>1HTL*DB)PD@#E"1X`0``2,'I`DP)\4R)[H/A_TC!Y@5.C20B2(G*2#'J
M3#'Z20'43(GJ2,'J&T@)\DB)QD:-)"),B?I)P><>2,'J`DP)^DV)YH/B_T@#
MM"2``0``2<'F!4B-+"Y(B=9(,<Y,,>Y(`?5,B>9(P>X;3`GV08GN0HTL-DR)
M[DG!Y1Y(P>X"3`GN28G%3`.L)(@!``"#YO])B>Y)P>8%28U,#0!)B?5),=5-
M,>5.C2PI2(GI2,'I&TP)\4:-+"E,B>%)P>0>2,'I`DP)X4F)Q$P#I"20`0``
M@^'_38GN2<'F!4F-%!1)B<Q),?1),>Q.C20B3(GJ2,'J&TP)\D:-)")(B>I(
MP>4>2,'J`D@)ZDB)Q4@#K"28`0``@^+_38GF2(UT-0!(B=5(,<U,,>U)P>8%
M2(TL+DR)YDC![AM,"?9!B>]"C2P^3(GN2<'E'DC![@),">Y)B<5,`ZPDH`$`
M`(/F_TF)[DG!Y@5)C4P-`$F)]4DQU4TQY4Z-+"E(B>E(P>D;3`GQ1HTL*4R)
MX4G!Y!Y(P>D"3`GA28G$3`.D)*@!``"#X?]-B>Y)P>8%28T4%$F)S$DQ]$DQ
M[$Z-)"),B>I(P>H;3`GR1HTD(DB)ZDC!Y1Y(P>H"2`GJ2(G%2`.L)+`!``"#
MXO]-B>9)P>8%2(UT-0!(B=5(,<U,,>U(C2PN3(GF2,'N&TP)]D&)[D*-+#9,
MB>Y)P>4>2,'N`DP)[DF)Q4P#K"2X`0``@^;_28GN2<'F!4F-3`T`28GU23'5
M33'E3HTL*4B)Z4C!Z1M,"?%&C2PI3(GA2<'D'DC!Z0),">%)B<1,`Z0DP`$`
M`(/A_TV)[DG!Y@5)C10428G,23'T23'L3HTD(DR)ZDC!ZAM,"?)&C20B2(GJ
M2,'E'DC!Z@)(">I(B<5(`ZPDR`$``(/B_TV)YDG!Y@5(C70U`$B)U4@QS4PQ
M[4B-+"Y,B>9(P>X;3`GV08GO0HTL/DR)[DG!Y1Y(P>X"3`GN28G%3`.L)-`!
M``"#YO])B>Y)P>8%28U,#0!)B?5),=5-,>5.C2PI2(GI2,'I&TP)\4:-+"E,
MB>%)P>0>2,'I`DP)X4F)Q$P#I"38`0``@^'_38GN2<'F!4F-%!1)B<Q),?1)
M,>Q.C20B3(GJ2,'J&TP)\D:-)")(B>I(P>4>2,'J`D@)ZDB)Q4@#K"3@`0``
M@^+_38GF2<'F!4B-=#4`2(G52#'-3#'M2(TL+DR)YDC![AM,"?9!B>Y"C2PV
M3(GN2<'E'DC![@),">Y)B<5,`ZPDZ`$``(/F_TF)[DF-3`T`28GU23'52<'F
M!4TQY4Z-+"E(B>E(P>D;3`GQ1HTL*4R)X4G!Y!Y(P>D"3`GA28G$3`.D)/`!
M``"#X?]-B>Y)P>8%28T4%$F)S$DQ]$DQ[$Z-)"),B>I(P>H;3`GR1HTD(DB)
MZDC!Y1Y(P>H"2`GJ2(G%2`.L)/@!``"#XO]-B>9(`X0D``(``$G!Y@5(C70U
M`$B)U4@QS4B-#`A,,>U(C2PN3(GF2,'N&TP)]D&)[TR)Y4:--#Y,B>Y)P>4>
M2,'N`DC![0),">Y-B>5'C0P.@^;_2<'E'DB)\$P)[4@QT$0!U0':3#'@38GT
M1`'>2`'!3(GP2<'D!4C!Z!M,">`!R$:-!`!,B0=(B6\03(E/"$B)=QA(B5<@
M2('$$`(``%M=05Q!74%>05_##Q]$``!,B60DX$R)?"3X,<!(B5PDT$B);"38
M28G\3(EL).A,B70D\$B#[#A(A?])B?=U*4B+7"0(2(ML)!!,BV0D&$R+;"0@
M3(MT)"A,BWPD,$B#Q#C#9@\?1```3(LU08L@`$V%]G3+#[8'/#UT!(3`=4E%
M,>U)BQXQP$B%VW2S36/M3(GU9@\?1```3(GJ3(GF2(G?Z*KC__^%P'4'0H`\
M*SUT-TB#Q0A(BUT`2(7;==HQP.EZ____#Q\`28G]28/%`4$/MD4`/#UT!(3`
M=>]%*>7KH0\?@`````!,*?5*C40K`4C!_0-!B2_I0____P\?0`!(@^P8,<!(
MC70D#.@`____2(/$&,-F9BX/'X0``````%5(B?U32(/L&$B-7"0,9I`QP$B)
MWDB)[^C3_O__2(7`="A(8T0D#$C!X`-(`P5>BB``9@\?1```2(/`"$B+$$B%
MTDB)4/AU\.O&2(/$&%M=PV9F9F9F9BX/'X0``````%4Q_U-(@^P(Z%/F__^+
M..B\X?__2(G'Z,3A__](BP`Q_TB+:`CH-N;__XLXZ)_A__](B<?H5^+__S'_
M#[88Z!WF__^+.(/C?^B#X?__2(G'Z$OB__](BP`Q_P^W0"#!X`<)V&:)10+H
M].7__XLXZ%WA__](B<?H9>'__TB+`#'_2(M8".C7Y?__BSCH0.'__S'2OMY>
M0`!(B<?H0>7__S'_2(E#*.BVY?__BSCH'^'__TB)Q^@GX?__2(L`,?](BU@(
MZ)GE__^+..@"X?__2(G'Z(KA__](BP`Q_TB)0S#H?.7__XLXZ.7@__](B<?H
M[>#__TB+`#'_2(M8".A?Y?__BSCHR.#__TB)Q^A0Y/__,=)(@S@`="`Q_^A!
MY?__BSCHJN#__TB)Q^@RY/__2(L`2(N0J````$B)4S@Q_^@=Y?__BSCHAN#_
M_TB)Q^B.X/__2(L`,?](BT`(2,=`0`````#H^.3__XLXZ&'@__](B<?H:>#_
M_TB+`#'_2(M`"$C'0"``````Z-/D__^+..@\X/__2(G'Z$3@__](BP`Q_TB+
M6`CHMN3__XLXZ!_@__](B<?H5^3__TB+`$B)0TA(@\0(6UW#9@\?A```````
M2(E<)-A(B6PDX$B)^TR)9"3H3(EL)/!,B70D^$B![+@```!(A?]T!8`_`'4S
M2(N<))````!(BZPDF````$R+I"2@````3(NL)*@```!,B[0DL````$B!Q+@`
M``###Q\`Z+OA__](A<!(B<5TP`\?`$B)[^A(Y/__2(7`#X3'````3(UP$P^V
M%:4>```/MD`3.=!U%`^V%9<>``!!.%8!=,\/'X``````#[85@1X``#G0#X2I
M````2(G?Z%'A__],B?=)B<3H1N'__T6-9`0"26/\Z#G@__]-B?%(B<=)B<1)
MB=BY$UU``$C'PO____^^`0```#'`Z#7C__](B>),B>:_`0```.C5XO__@_C_
M=!"+1"08)0#P```]`$```'1P3(GGZ#C@__],B>?HT.#__TB)[^B(X___2(7`
M#X5`____#Q^``````$B)[^C0XO__2(G?Z!C@___IT/[__P\?``^V!<H=``!!
M.$8!#X5&____#[85NAT``$$X5@(/A.[^___I,/___V8/'X0``````$R)Y^AH
M_O__ZXYF#Q]$``!5,>U32(G[,?](@^P(Z-[B__^+..A'WO__2(G'Z-_A__](
MB=Y(B<*_`0```.A/X?__A<!T"TB#Q`B)Z%M=PV:0,?_HJ>+__XLXZ!+>__](
MB<?HJN'__XM`&"4`\```/0!```!T)3'_Z(3B__^+..CMW?__2(G'Z(7A__^+
M0!@E`/```#T`H```=:M(B=^^`@```#'MZ!?B__^%P$`/E,5(@\0(6XGH7<,/
M'X0``````$B)7"302(EL)-@QP$R)9"3@3(EL).A(B?-,B70D\$R)?"3X2(/L
M6(`^/4F)_`^4P$@!PTB)W^B%W___2(UT)!Q!B<5,B><QP.@C^O__2(7`2(G%
M=%M(B<?H8]___T2)ZD@YT`^"U@$```\?@``````/M@-(@\,!B$4`2(/%`83`
M=>XQP$B+7"0H2(ML)#!,BV0D.$R+;"1`3(MT)$A,BWPD4$B#Q%C#9@\?A```
M````3(LU684@`#'MOA````!)@SX`="-,B?!F#Q^$``````!(@\`(@\4!2(,X
M`'7SC74"2&/V2,'F`XL%@X4@`(7`#X3[````3(GWZ!/A__])B<=(B04)A2``
M2&/-387_N/____\/A&S___])QT3/"`````");"0<00^V!"2$P`^$%@$``#P]
M#X0.`0``3(G@ZP60A-)T#$B#P`$/MA"`^CUU\$4IY8GM2,'E`T&-?`4"2`,M
MJX0@`.A6W?__2(G"2(722(E%`+C_____#X0%____BU0D'$B+!8:$(`!(BQ30
M00^V!"2$P(@"="8\/70B28/$`>L)#Q]$```\/70300^V!"1(@\(!28/$`83`
MB`)UZ<8"/4B#P@%F+@\?A```````#[8#2(/#`8@"2(/"`83`=>_IG/[__V8N
M#Q^$``````!(B??'!7.$(``!````Z+[<__])B<>X_____TV%_P^$<?[__TAC
MS4R)]DR)_TB-%,T`````2(E,)`CH@M[__TR)/=N#(`!(BTPD".G9_O__BVPD
M'.G=_O__3(G@Z0#___](@^P(,?_HY=___XLXZ$[;__^Y&5U``+I`($``OB-=
M0`!(B<=(@\0(Z:/?__\/'P!(@^P(,?_HM=___XLXZ![;__](B<?HMO___S'_
MZ)_?__^+..@(V___0;C>7D``13')NF!40`!,B<&^/UU``$B)QTB#Q`CI9MW_
M_V8/'T0``$B)7"3H2(EL)/`Q[4R)9"3X2('L."```$B-G"00$```9$B+!"4H
M````2(F$)!@@```QP.A(W/__0;GO7D``08G`N51=0``QP+H!$```O@$```!(
MB=_HMM[__X7`>3I(BY0D&"```&1(,Q0E*````$B)Z'5E2(N<)"`@``!(BZPD
M*"```$R+I"0P(```2('$."```,,/'T``2(G?N@`0``!(B>;H"-W__X7`B<-X
ML(U[`4AC_^@WV___2(7`2(G%=)U(8]M(B>9(B<=(B=KH_MS__\9$'0``ZX7H
M8MW__V:0Z1O___]F9BX/'X0``````$%7059!54%428GT54B)_;]@74``4TB!
M["@0``!D2(L$)2@```!(B80D&!```#'`Z&SW__^^+P```$B)[TB)P^B\W/__
M2(7`=#M(B>Z_:5U``#'`Z.C[__](BY0D&!```&1(,Q0E*````$B)Z`^%8`$`
M`$B!Q"@0``!;74%<05U!7D%?PTB)[^ATV___OG9=0`!,B>=!B<;HU-S__TB%
MP$F)QW2E3(UD)!!!O1%=0`!!@\8!#Q]$``!!@#\`30]$_4B%VW033(G^2(G?
MZ)#<__^%P`^$KP```$R)_^@@V___2&/008!\%_\O=1A)C507_TB)T<8"`(/H
M`4B#Z@&`>?\O=.U!C00&/?\/```/CS?___]!N7A=0`!-B?BYCUY``+H`$```
MO@$```!,B><QP$B)+"3HZ-S__S'_Z$'=__^+..BJV/__2(G'Z$+<__],B>9(
MB<*_`0```.ARW/__A<!U)3'_Z!?=__^+..B`V/__2(G'Z!C<__^+0!@E`/``
M`#T`@```=!TQ_[YV74``Z-W;__](A<!)B<</A1G____II?[__[X!````3(GG
MZ(_<__^%P'723(GFOVE=0`#H?OK__TR)Y^@&VO__2(G%Z8;^___H>=O__V8/
M'X0```````^V#TB)^(3)=!A(C5<!9I"`^2\/M@I(#T3"2(/"`83)=>[SPV9F
M9BX/'X0``````$B%_U-(B?MT)X`_`'0BZ-W9__](C50#_T@YTW(,ZS^02(/J
M`4@YTW,U@#HO=/+K);\"````Z+;8__](A<!T!6;'`"X`6\-F+@\?A```````
M@#HO=`E(@^H!2#G3<O)(.=IU%8`Z+W106[]X74``Z4W9__\/'T0``$B#Z@%(
M.=-S!8`Z+W3R2"G:,<!(C4H"2('Y`!```'>L2(G>2(/"`;D`$```O\#&8`#H
M<M?__[C`QF``6\,/'P"_`@```.@NV/__2(G",<!(A=(/A'3___]FQP(N`$B)
MT%O#9@\?1```2(/L.+]Z74``9$B+!"4H````2(E$)"@QP$B+!0`8``!(B00D
M2(L%_1<``$B)1"0(2(L%^1<``$B)1"002(L%]1<``$B)1"08#[<%\1<``&:)
M1"0@,<#H=?3__S'`OX-=0`#H:?3__S'`OXM=0`#H7?3__S'`OY1=0`#H4?3_
M_S'`OYM=0`#H1?3__S'`OZM=0`#H.?3__S'`OV!=0`#H+?3__S'`O[==0`#H
M(?3__S'`O\%=0`#H%?3__S'`O\M=0`#H"?3__S'`OVE=0`#H_?/__S'`O]5=
M0`#H\?/__S'`O]Y=0`#HY?/__S'`O^E=0`#HN?/__TB%P'0/2(G&O\%=0``Q
MP.A%^/__,<"_^EU``.B9\___2(7`=`](B<:_#%Y``#'`Z"7X__\QP+\77D``
MZ'GS__](A<!T/$B)QK]@74``,<#H!?C__S'`OD->0`"_FUU``.CT]___2(M$
M)"AD2#,$)2@```!U6DB#Q#C##Q^``````#'`OR=>0`#H+//__TB%P'072(G&
MO[==0``QP.BX]___Z[%F#Q]$``!(C70D$;\X7D``N0H```#SIG682(UT)!N_
MMUU``#'`Z(SW___KA>B5V/__#Q]$``!(@^P(BP5R?2``@_C_=`E(@\0(PP\?
M0``QP+^W74``Z+SR__](B<(QP$B%TG0/#[82A-)T"#'`@/HP#Y7`B04Y?2``
M2(/$",,/'X0``````$B#[`CHA]C__XG'Z(#6__](B<(QP$B%TG0#2(L"2(/$
M",-F9F9F9BX/'X0``````$%6055!5$F)_%53NT]>0`!(@^Q`2,=$)!!/7D``
M2,=$)!A%7D``2(UL)!A(QT0D(%)>0`!(QT0D*$A>0`!(QT0D,$U>0`!(QT0D
M.-Y>0`#K)`\?@`````!,B>9(B<?H_=;__TB%P'102(M=`$B#Q0B`.P!T,3'`
M2(G?Z.'Q__](A<!)B<9T!8`X`'7,2(G?,<!,B>;H9_;__TB+70!(@\4(@#L`
M=<](@\1`6UU!7$%=05[##Q]$``!,B>?H`-;__TR)]TF)Q>CUU?__28U\!0+H
MZ]3__T&Y=EU``$F)Q4B)QTV)X+F/7D``2,?"_____[X!````,<!,B30DZ.#7
M__],B>Y(B=\QP.CS]?__Z5;___]F9F9F9BX/'X0``````$%7059!54%455-(
MB?N_8%U``$B![)B!``!D2(L$)2@```!(B80DB($``#'`2,>$)(````!K7D``
M2,>$)(@```!S7D``2,>$))`````174``2,>$))@```#>7D``2,=$)%`,7D``
M2,=$)%@%7D``2,=$)&!X7D``2,=$)&AN7D``2,=$)'"`7D``2,=$)'C>7D``
M2,>$)*````!?7D``2,>$)*@```"$7D``2,>$)+````#>7D``Z(7P__](A<!T
M"8`X``^%!P,``#'`Z.#]__](A<!)B<8/A!P#``!!#[8N0(3M="?H]M3__TR)
M\@\?`$B+"$@/ONWV!&D(=0/&`E](@\(!#[8J0(3M=>1!O`$```"_#%Y``.L<
M#Q^``````$ECQ$&#Q`%(BWS$4(`_``^$,P(``#'`Z`3P__](A<!(B<5TW$B)
MQ^CD\___A<!TT$B)[^@8U/__2(7`28G%=,!,B>_H.-3__TR)]TB)Q>@MU/__
MB>I$C:0"!`0``$UCY$R)Y^@8T___3(GG2(G%2(E$)#CH"-/__T&Y>%U``$V)
MZ+F-7D``2,?"_____TB)QTF)Q+X!````,<!,B70D"$C'!"267D``Z/35__^^
M[0$``$R)Y^B'UO__,<"_2%Y``.A;[___2(7`#X1B`@``2(G'Z'K3__](BSM(
MB<;HG_?__TB%P$F)Q0^$0P(``$R)[^B+T___@_@#?C9(8]"_FUY``+D%````
M28UT%?SSIG4@@_@$#X3_!@``@^@$2)A!@'P%_R\/A.X&``!F#Q]$```QP.@)
M_/__A<!U%3'V3(GOZ,O3__^%P$&)QP^%\`$``+Y#7D``O[==0``QP.A?\___
MZ*K2__]!N7A=0`")!"1-B>"YN5Y``$C'PO____^^`0```$B)[S'`2,=$)`C>
M7D``,=OH"-7__^M,9@\?1```Z`O4__^#.!%U3NAATO__@\,!B00D0;EX74``
M38G@N<=>0`!(Q\+_____O@$```!(B>\QP$C'1"00WEY``(E<)`CHNM3__[[M
M`0``2(GOZ$W5__^#^/]TJ$R)Y^APTO__OV!=0`!(B>XQP.BQ\O__2(GOZ*G[
M__](BY0DB($``&1(,Q0E*````$B+1"0X#X6T!@``2('$F($``%M=05Q!74%>
M05_##Q\`2(NL)(````!!O`$```"`?0``=1GK0F:026/$08/$`4B+K,2`````
M@'T``'0K2(GOZ)/Q__^%P'3?2(GOZ,?1__](A<!)B<5TS^FJ_?__9BX/'X0`
M`````$4Q[>F8_?__#Q^$``````!(B<=(B40D*.@#^___2(M$)"A(B<?HAM'_
M_TB)1"0XZ4/___\/'T``O0$```"_7UY``&8/'T0``#'`Z#'M__](A<!T%$B)
MQ^A4T?__2(7`28G&#X6T_/__2&/%@\4!2(N\Q*````"`/P!US4&^9%Y``.G&
M_/__9BX/'X0``````$R+*^FU_?__#Q^$``````!,C;0DP````+H"````2,?&
M[O___XG'Z!73__^Z!@```$R)]D2)_^CUS___@+PDP`````!U#H"\),$```!#
M#X0#!0``3(VL),"````QTC'V1(G_NXFKS>_HU-+__TF-13BY_MRZF+KPX=+#
M2,>$),"````!(T5G2(F<),B```!(B8PDT(```$C'A"38@```=E0R$$B)E"3@
M@```2,>$).B`````````2,>$)/"`````````QX0D.($```````!(B40D0&8/
M'T0``+H`@```3(GV1(G_Z$C/__^%P(G##XZ&`0``2(N,).B```!(8\.+O"0X
M@0``3(GVC13!2#G*2(F4).B````/DL%(P>@=#[;)2`&,)/"```!(`80D\(``
M`(7_=&6Y0````"GY2&/_.<L/3LM(`WPD0$ACT8E,)#!(B50D2.C8T/__BX0D
M.($``(M,)#`!R(/X0(F$)#B!```/A6/___](BW0D2$R)[RG+28TT-DB)="0P
MZ*/3__](BW0D,&8/'T0``(/[/P^.LP```#'`#Q]$``!(BQ0&3(GO2(F4)/B`
M``!(BU0&"$B)E"0`@0``2(M4!A!(B90D"($``$B+5`882(F4)!"!``!(BU0&
M($B)E"08@0``2(M4!BA(B90D(($``$B+5`8P2(F4)"B!``!(BU0&.$B)1"0H
M2(ET)#!(B90D,($``.@/T___2(M$)"B)VDB+="0P2(/`0"G"@_H_#X]L____
M@^M`B=K!Z@:)T,'B!DC!X`8ITTB-=#!`2(M\)$!(8].Y2````.AJSO__B9PD
M.($``.EF_O__9@\?1```1(G_Z!#-__](BYPDZ(```$R+M"3P@```2(G82,'H
M`X/@/TACT(/``8/X.,:$%/B```"`#X]P`@``NC@````Q]BG"2)A)C7P%.$AC
MTNBGS/__3(GP3(GO1(BT)#.!``!(P>@8B)PD-X$``$R-K"1Q@0``B(0D,($`
M`$R)\$C!Z!"(A"0Q@0``3(GP3(VT)$"!``!(P>@(B(0D,H$``$B)V$C!Z!B(
MA"0T@0``2(G82,'H$(B$)#6!``!(B=@QVTC!Z`B(A"0V@0``Z.K1__](BX0D
MP(```$B)PHB$)'.!``!(P>H808G0B)0D<($``$B)PDC!ZA"(E"1Q@0``2(G"
M2(N$),B```!(P>H(B)0D<H$``$B)PHB$)'>!``!(P>H8B)0D=($``$B)PDC!
MZA"(E"1U@0``2(G"2(N$)-"```!(P>H(B)0D=H$``$B)PHB$)'N!``!(P>H8
MB)0D>($``$B)PDC!ZA"(E"1Y@0``2(G"2(N$)-B```!(P>H(B)0D>H$``$B)
MPHB$)'^!``!(P>H8B)0D?($``$B)PDC!ZA"(E"1]@0``2(G"2(N$)."```!(
MP>H(B)0D?H$``$B)PHB$)(.!``!(P>H8B)0D@($``$B)PDC!ZA"(E"2!@0``
M2(G"2,'J"(B4)(*!``#K$0\?A```````10^V10!)@\4!28T\'C'`10^VP+FT
M7D``2,?"_____[X!````2(/#`NC3SO__2(/[*'7-QH0D:($```!!N7A=0`!-
MB>"YI5Y``$C'PO____^^`0```$B)[S'`2,=$)`C>7D``3(DT).B4SO__Z>?Y
M__\/'X``````2(M;"$B%VP^$"_G__TB)W^A3S/__2(/X`P^&^?C__TB-=`/\
MOZ!>0`"Y!0```/.F3`]$Z^G?^/__38U].+I`````,?8IPDB828T\!TACTN@T
MRO__3(GOZ.S/__^Y!P```#'`3(G_\TBKZ7/]__^`O"3"````00^%[_K__X"\
M),,```!##X7A^O__@+PDQ````$@/A=/Z__^`O"3%````10^%Q?K__T2)_[H"
M````2,?&QO___^B>S?__NBD```!,B?9$B?_H?LK__^GT_O__Z.3,__\/'T``
M058Q_T%505154TB![!`0``!D2(L$)2@```!(B80D"!```#'`Z.?-__^+..A0
MR?__2(G'Z'C+__^_FUU``,8``3'`Z.GF__](A<!T"8`X,0^$NP(``#'`Z"3R
M__\Q_^BMS?__BSCH%LG__[D+````N@$```"^V%Y``$B)Q^A/RO__2(7`#X2W
M````2(M`$#';3(M@*(L%EG$@`(/X`0^.DP```+T(````ZS)F#Q]$``!)BW40
M2(L%;7$@`$B+/"CH+,S__X7`=6B#PP&+!5]Q(`!(@\4(C5,!.=!^6C'_Z"W-
M__^+..B6R/__,<F)VDR)YDB)Q^AGR___2(7`=#),BRA!]D4-!'6H,?_H`<W_
M_XLXZ&K(__],B>ZY`@```#'22(G'Z$C-__](B<;KAP\?`(L%^G`@`(U0_SG:
M#X1O`0``,?_HR,S__XLXZ#'(__^Y!````+H!````OMU>0`!(B<?H:LG__TB%
MP$B)PW0V2(M`$#'_2(LHZ)3,__^+..C]Q___NM]>0`!(B<=(B>[H;<G__TB+
M0Q!(BQCV0PY`#X5,`0``,?_H9<S__XLXZ,['__^Y!````+H!````ON==0`!(
MB<?H!\G__TB%P$B)PW0[,<"_:5U``.A3Y?__2(7`28G$#X0_`0``2(M#$#'_
M2(LHZ!G,__^+..B"Q___3(GB2(GN2(G'Z/3(__\Q_^C]R___BSCH9L?__TB)
MQ^B.R?__,?_&``#HY,O__XLXZ$W'__](B<?H]<O__[]@74``2,<``````#'`
MZ.+D__](A<!(B07@;R``#X1S`0``ONT!``!(B<?HY<O__X/X$70-A<!T"8/X
M_P^%Q`$``$B+A"0($```9$@S!"4H````9I`/A:8!``!(@<00$```6UU!7$%=
M05[#9BX/'X0``````(/X`0^.B/[__[L!````9I`Q_X/#`>A&R___BSCHK\;_
M_TR)YDB)Q^CDQ___.1U.;R``?]SI6/[__P\?@``````Q_^@9R___BSCH@L;_
M_TB)WDB)Q^C'R?__Z9;^__]FD(!X`0`/A$+]__]F#Q]$``#I,/W__P\?`$B+
M!?EN(``Q_TR+,$B+0Q!,BR#HT,K__XLXZ#G&__^Z_P\``$B)YK_D7D``Z/?(
M__^%P$&)Q7Y008U%_TACT(`\%`!U!X7`=#]!B<5-8^V^+P```$B)YTR)ZNAI
MQO__2(7`="0Q_^A]RO__BSCHYL7__TR)Z4B)XDR)YDB)Q^B5R/__Z5S^__\Q
M_^A9RO__BSCHPL7__TR)\DR)YDB)Q^@TQ___Z3O^__](BSU0;B``Z!/R__](
MB054;B``2(M#$$B++3EN(`!,BR!!]D0D#00/A(0```!)BT0D$$B)[DB)Q^@2
MQO__B<5(BT,02(L8]D,-!'1#2(M#$$B)PDB+!?UM(`")Z;\H7T``2(LP,<#H
M!,G__^B?R/__B<%(BP7>;2``2(L5YVT@`+]87T``2(LP,<#HX,C__S'_Z*G)
M__^+..@2Q?__N0(````QTDB)WDB)Q^CPR?__ZY\Q_^B'R?__BSCH\,3__[D"
M````,=),B>9(B<?HSLG__^E<____9@\?A```````54B)_5-(@^P(Z.+L__\/
MMA!(B<.$TG0:2(U``0\?0`"`^B\/MA!(#T382(/``832=>XQP.AG[___A<!T
M'4B%[708@'T``'02OI9>0`!(B=_H*\?__T@YV'0'2(/$"%M=PTB#Q`A(B>];
M7>EAY/__D$B#[`@Q_^CER/__BSCH3L3__[[_____2(G'Z#'&__\Q_^C*R/__
MBSCH,\3__S'2OA`\0`!(B<=(@\0(Z0#)__]32(/L((E\)!Q(B70D$$B-?"0<
M2(E4)`A(C70D$$B-5"0(Z'G(__^Z8!Y``+]0($``2(G6Z/<!```Q_^BPQ?__
M@#@`=3;HEL7__TB%P$B)!6QL(``/A+8!``!(B<?H3L;__S'_Z$?(__^+..BP
MP___2(G'Z'C'___&```Q_^@NR/__BSCHE\/__TB)Q^@OR/__@`@",?_H%<C_
M_XLXZ'[#__](B<?H%LC__X`(`8M\)!R#QP5(8_](A?\/B!@!``#R2`\JQ_(/
M6`4;!0``9@\N!1L%```/AS\!``!(P><#Z"S'__](BW0D$$B)!=AK(`!(BQ9(
MQT`(\UY``$C'0!#`7T``2,=`&/9>0`!(B1"+5"0<QP6T:R``!````(/Z`7XB
MC4K^2(T\S0@````QR6:02(M<#@A(B5P(($B#P0A(.?EU[8U*!$4QP(/"`[ZP
M0D``2&/)2,=$R/@`````2(L]7&L@`$B)P>@4P___A<")PW0^2(L]1VL@`.C2
MQ?__,<"_JUU``.A&X/__2(7`=#%(BSTJ:R``Z*7"___HP,3__XG82(/$(%O#
M#Q^$``````!(BST):R``Z)3#__^)P^NR2(L]$6L@`$B%_W0IZ'_]___KO`\?
M1```2(GX2(GZ2-'H@^(!2`G0\D@/*L#R#UC`Z=#^__^_8%U``.C1W___2(7`
M2(G'2(D%S&H@`'2!Z[R_`0```.BVPO__OE#&8`"_75U``#'`Z+7%__^0D)"0
MD$B-!1$!``!(A<!T#$B+#04!``#IN,+__S')Z_>0D)"02(EL)-A,B60DX$B-
M+1ME(`!,C24492``3(EL).A,B70D\$R)?"3X2(E<)-!(@^PX3"GE08G]28GV
M2,']`TF)U^ACP?__2(7M=!PQVP\?0`!,B?I,B?9$B>]!_Q3<2(/#`4@YZW+J
M2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,,/'X``````\\.0
MD)"0D)"0D)"0D)"0D%5(B>532(/L"$B+!8!D(`!(@_C_=!F[0,%@``\?1```
M2(/K"/_02(L#2(/X_W7Q2(/$"%O)PY"02(/L".@_QO__2(/$",,`````````
M`````0`"`````````````````"XN`"5S+R5S`'!E<FQX<VDN8P!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R
M;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!0
M15),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`
M4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2
M`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`55-%4@!3
M65-414T`0SI<5$5-4``O=&UP`%1%35!$25(`5$U0`%5315).04U%`"5S)7,E
M<R5S`'!A<BT`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"]P<F]C+W-E
M;&8O97AE`"UE`"TM``````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(```````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A
M8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M
M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H
M("5I+@H``````````````````````,!#<&%R+G!L```C(2]U<W(O8FEN+W!E
M<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A
M8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U
M<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I
M8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U
M:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@
M("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@
M<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H
M(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*
M("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@
M("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T
M96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY
M(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG
M('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T
M:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@
M("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E
M<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@
M86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S
M<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S
M('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@
M("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@
M("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^
M(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A
M<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@
M("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@
M("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@
M("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@
M("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE
M*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V
M86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!
M4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M
M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@
M+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@
M(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF
M("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%4
M2`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@
M("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I
M.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N
M9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#
M:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM[
M"B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I
M;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R
M.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F
M(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K
M*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D
M9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%
M>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R
M97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]
M("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T
M96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@
M<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY
M("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*
M("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@
M("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN
M="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F
M+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@
M("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*
M("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D
M:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I
M('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O
M.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@
M("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92([
M"@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT[
M"B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T
M=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M
M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O
M=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O
M=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\
M)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L
M960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@
M<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@
M4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP
M97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@
M(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*
M("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@
M("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!
M8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@
M("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@
M("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*
M(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP
M:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@
M8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U
M("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@
M('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I
M;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'
M4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE
M(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE
M"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA
M;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6
M.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@
M("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*
M("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*
M("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@
M("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G
M*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@
M("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D
M<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@
M("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC
M*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@
M("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*
M(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O
M=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]
M"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*
M("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@
M("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`]
M(&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T
M<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F
M:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D
M:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@
M9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@
M(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@
M("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L
M"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@
M("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@
M<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G
M.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD
M968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[
M>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@
M("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I
M.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T
M:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@
M("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H
M)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.
M0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!2
M5"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y
M(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX
M+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E
M97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P
M;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H
M870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E
M;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M
M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D
M9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E
M=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@
M(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@
M(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I
M9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@
M("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@
M("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@
M("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2![
M"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@
M("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@
M(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@
M("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@
M;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM
M96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y
M("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@
M(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@
M("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@
M<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@
M?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I
M;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@
M3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI
M8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@
M("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@
M("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@
M("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX
M.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@
M("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF
M("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613
M:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T
M:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N
M86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@
M("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@
M("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E
M<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER
M92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R
M<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X
M<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ
M5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,
M;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA
M;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R
M97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U
M:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#
M=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E
M<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N
M8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S
M('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R
M971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@
M("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@
M("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E
M<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*
M("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@
M("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ
M."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@
M("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@
M("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E
M860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<
M,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$
M:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`]
M(#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@
M("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@
M7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@
M*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP
M+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@
M("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@
M("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N
M86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@
M9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I
M;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R
M;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$[
M"B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE
M+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@
M("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E
M='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@
M(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX
M7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@
M;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B
M(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@
M("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]
M*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@
M(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@
M("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O
M=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2![
M"B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@
M>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC
M('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@
M("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E
M(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH````!&P,[X````!L````D:/__
M_````/1^__],`0``Y'___W0!```$@/__C`$``&2`__^\`0``-(+__^P!``#4
M@___%`(``(2$__],`@``U(;__WP"```$A___E`(``%2'__^L`@``-(C__]0"
M``!$B/__[`(``"2*__\\`P``5(K__U0#```TB___A`,```2-__^D`P``5(W_
M_\0#``"$C?__W`,``*2.__\D!```M)C__W0$``!DG?__O`0``-2=___T!```
M%)[__PP%``!$H/__-`4``&2@__],!0``]*#__W0%```4``````````%Z4@`!
M>!`!&PP'")`!``!,````'````"!G___+%@```$(.$$0.&$(.($(.*$$.,$$.
M.$2#!X8&C`6-!(X#CP)'#L@$`ZD6#CA!#C!!#BA"#B!"#AA"#A!"#@@`````
M`"0```!L````H'W__^P`````688&@P>/`HP%3@Y`2(X#C01B"@X(1PL4````
ME````&A^__\5`````$0.(%`."``L````K````'!^__]1`````$$.$$.&`D$.
M&$0.,$6#`P)`#AA!#A!!#@@````````L````W````*!^___'`0```$$.$$,.
M&$0.((,#A@(#O`$.&$$.$$$."``````````D````#`$``$"`__^:`0```$V&
M!8,&5@[``46.`HT#C`1T"@X(1`L`-````#0!``"X@?__J`````!!#A!"A@)!
M#AA#@P-&#B!L"@X80PX000X(0PL"8PX800X00PX(```L````;`$``#""__]0
M`@```%F-!(P%A@:#!TX.8$^/`HX#`G`*#@A*"P`````````4````G`$``%"$
M__\M`````$0.$&0."``4````M`$``&B$__]*`````$0.$`)!#@@D````S`$`
M`*"$___>`````$R&`X,$3`[`0%N,`@)@"@X(10L`````%````/0!``!8A?__
M!0``````````````3`````P"``!0A?__UP$```!"#A!"#AA"#B!"#BA#C`6-
M!(X#CP)!#C!#A@9&#CA'#N`@4X,'`DH*#CA!#C!!#BA"#B!"#AA"#A!"#@A!
M"P`4````7`(``."&__\D```````````````L````=`(``/B&___:`````$0.
M$$.#`GX*#@A+"UD*#@A/"WP*#@A$"V$."``````<````I`(``*B'___+`0``
M`$0.0`-L`0H."$@+`````!P```#$`@``6(G__T@`````1`X03PH."$4+;PX(
M````%````.0"``"(B?__(@````!$#A!=#@@`1````/P"``"@B?__$@$```!"
M#A!"#AA"#B!#C`2-`XX"00XH00XP18,&A@5$#G`"E@H.,$$.*$$.($(.&$(.
M$$(."$8+````3````$0#``!XBO__#`H```!"#A!"#AA"#B!"#BA!#C!!#CA#
M@P>&!HP%C02.`X\"3`[0@P(#00,*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P!$
M````E`,``#B4__^G!````$(.$$0.&$(.($$.*$$.,$<.P"!3@P:&!8P$C0..
M`@-Y`@H.,$$.*$$.($(.&$(.$$(."$L+```T````W`,``*"8__]O`````$$.
M$$.&`D$.&$0.((,#`E4*#AA!#A!!#@A!"T0.&$0.$$$."````!0````4!```
MV)C__T``````1`X0=PX(`"0````L!````)G__RL"````00X01`XP78,"`X0!
M"@X000X(20L````4````5`0```B;__\<```````````````D````;`0``!";
M__^)`````%&,!88&7PY`1H,'CP*.`XT$`E(."```%````)0$``!XF___`@``
M``````````````````````#__________P``````````__________\`````
M`````````````````0`````````!``````````$`````````K0(````````!
M`````````+P"`````````0````````#(`@````````$`````````TP(`````
M```!`````````-T"`````````0````````#K`@````````$`````````^`(`
M```````!`````````$<#````````#P````````"E!`````````P`````````
MN!U````````-`````````.A<0```````]?[_;P````!@`D````````4`````
M````2`Y````````&`````````&@#0```````"@`````````_!@````````L`
M````````&``````````5`````````````````````P````````"0PV``````
M``(`````````@`<````````4``````````<`````````%P`````````X%D``
M``````<`````````\!5````````(`````````$@`````````"0`````````8
M`````````/[__V\`````<!5```````#___]O``````(`````````\/__;P``
M``"(%$``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````:,%@````````````````````````
M````YAU```````#V'4````````8>0```````%AY````````F'D```````#8>
M0```````1AY```````!6'D```````&8>0```````=AY```````"&'D``````
M`)8>0```````IAY```````"V'D```````,8>0```````UAY```````#F'D``
M`````/8>0```````!A]````````6'T```````"8?0```````-A]```````!&
M'T```````%8?0```````9A]```````!V'T```````(8?0```````EA]`````
M``"F'T```````+8?0```````QA]```````#6'T```````.8?0```````]A]`
M```````&($```````!8@0```````)B!````````V($```````$8@0```````
M5B!```````!F($```````'8@0```````AB!```````"6($```````*8@0```
M````MB!```````#&($```````-8@0```````YB!```````#V($````````8A
M0```````%B%````````F(4```````#8A0```````1B%```````!6(4``````
M`&8A0```````=B%```````"&(4```````)8A0```````IB%```````"V(4``
M`````,8A0```````UB%```````#F(4```````/8A0```````!B)````````6
M(D```````"8B0```````-B)```````!&(D```````%8B0```````9B)`````
M``!V(D```````(8B0```````EB)```````"F(D```````+8B0```````QB)`
M``````#6(D````````````#_____N%]```````#I6P```````$=#0SH@*$=.
M52D@-"XU+C`@,C`Q,#`W,38@*%)E9"!(870@-"XU+C`M,RD`1T-#.B`H1TY5
M*2`T+C4N,2`R,#$P,#@Q,B`H4F5D($AA="`T+C4N,2TQ*0``+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`
M+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"```````````"0```
M``````(````````<`````````````````````0```````````````````!,`
M```'`````@`````````<`D```````!P"````````(```````````````````
M``0````````````````````A````!P````(`````````/`)````````\`@``
M`````"0````````````````````$````````````````````-````/;__V\"
M`````````&`"0```````8`(````````$`0````````4`````````"```````
M`````````````#X````+`````@````````!H`T```````&@#````````X`H`
M```````&`````0````@`````````&`````````!&`````P````(`````````
M2`Y```````!(#@```````#\&```````````````````!````````````````
M````3@```/___V\"`````````(@40```````B!0```````#H``````````4`
M`````````@`````````"`````````%L```#^__]O`@````````!P%4``````
M`'`5````````@``````````&`````@````@```````````````````!J````
M!`````(`````````\!5```````#P%0```````$@`````````!0`````````(
M`````````!@`````````=`````0````"`````````#@60```````.!8`````
M``"`!P````````4````,````"``````````8`````````'X````!````!@``
M``````"X'4```````+@=````````&`````````````````````0`````````
M``````````!Y`````0````8`````````T!U```````#0'0```````!`%````
M```````````````$`````````!``````````A`````$````&`````````.`B
M0```````X"(````````(.@``````````````````$```````````````````
M`(H````!````!@````````#H7$```````.A<````````#@``````````````
M``````0```````````````````"0`````0````(``````````%U`````````
M70```````*I>```````````````````@````````````````````F`````$`
M```"`````````*R[0```````K+L```````#D````````````````````!```
M`````````````````*8````!`````@````````"0O$```````)"\````````
MK`0```````````````````@```````````````````"P`````0````,`````
M````0,%@``````!`P0```````!`````````````````````(````````````
M````````MP````$````#`````````%#!8```````4,$````````0````````
M````````````"````````````````````+X````!`````P````````!@P6``
M`````&#!````````"`````````````````````@```````````````````##
M````!@````,`````````:,%@``````!HP0```````"`"````````!@``````
M```(`````````!``````````S`````$````#`````````(C#8```````B,,`
M```````(````````````````````"``````````(`````````-$````!````
M`P````````"0PV```````)##````````F`(```````````````````@`````
M````"`````````#:`````0````,`````````*,9@```````HQ@```````!@`
M```````````````````(````````````````````X`````@````#````````
M`$#&8```````0,8```````"`$```````````````````(```````````````
M`````.4````!````,````````````````````$#&````````6```````````
M``````````$``````````0`````````!`````P``````````````````````
J``"8Q@```````.X````````````````````!````````````````````
